@@ -97,7 +97,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: NmapOps.cc 7752 2008-05-29 07:49:37Z michael $ */
+/* $Id: NmapOps.cc 8039 2008-06-08 05:29:00Z kris $ */
 #include "nmap.h"
 #include "nbase.h"
 #include "NmapOps.h"
@@ -456,7 +456,10 @@ void NmapOps::ValidateOptions() {
 
   if(ipoptions && osscan)
     error("WARNING: Ip options are NOT used while OS scanning!");
-    
+
+  /* Make sure nmap.registry.args is available (even if it's empty) */
+  if (!scriptargs)
+    scriptargs = strdup("");
 }
 
 void NmapOps::setMaxOSTries(int mot) {
