@@ -97,7 +97,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: NmapOps.h 7752 2008-05-29 07:49:37Z michael $ */
+/* $Id: NmapOps.h 8050 2008-06-08 15:34:07Z kris $ */
 
 #include "nmap.h"
 #include "global_structures.h"
@@ -244,7 +244,7 @@ class NmapOps {
 
   int max_ips_to_scan; // Used for Random input (-iR) to specify how 
                        // many IPs to try before stopping. 0 means unlimited.
-  int extra_payload_length; /* These two are for --data_length op */
+  int extra_payload_length; /* These two are for --data-length op */
   char *extra_payload;
   unsigned long host_timeout;
   /* Delay between probes, in milliseconds */
