@@ -98,7 +98,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: Target.cc 7640 2008-05-22 20:45:32Z fyodor $ */
+/* $Id: Target.cc 8081 2008-06-09 16:54:08Z kris $ */
 
 #ifdef WIN32
 #include "nmap_winconfig.h"
@@ -165,7 +165,6 @@ Target::~Target() {
 }
 
 void Target::FreeInternal() {
-
   /* Free the DNS name if we resolved one */
   if (hostname)
     free(hostname);
@@ -179,6 +178,12 @@ void Target::FreeInternal() {
   }
 
   if (FPR) delete FPR;
+
+  if (o.script) {
+    ScriptResults::iterator sriter;
+    for (sriter = scriptResults.begin(); sriter != scriptResults.end(); sriter++)
+      free((*sriter).id);
+  }
 }
 
 /*  Creates a "presentation" formatted string out of the IPv4/IPv6 address.
