@@ -6,17 +6,17 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2004 Insecure.Com LLC. Nmap       *
- * is also a registered trademark of Insecure.Com LLC.  This program is    *
- * free software; you may redistribute and/or modify it under the          *
- * terms of the GNU General Public License as published by the Free        *
- * Software Foundation; Version 2.  This guarantees your right to use,     *
- * modify, and redistribute this software under certain conditions.  If    *
- * you wish to embed Nmap technology into proprietary software, we may be  *
- * willing to sell alternative licenses (contact sales@insecure.com).      *
- * Many security scanner vendors already license Nmap technology such as  *
- * our remote OS fingerprinting database and code, service/version         *
- * detection system, and port scanning code.                               *
+ * The Nmap Security Scanner is (C) 1996-2008 Insecure.Com LLC. Nmap is    *
+ * also a registered trademark of Insecure.Com LLC.  This program is free  *
+ * software; you may redistribute and/or modify it under the terms of the  *
+ * GNU General Public License as published by the Free Software            *
+ * Foundation; Version 2 with the clarifications and exceptions described  *
+ * below.  This guarantees your right to use, modify, and redistribute     *
+ * this software under certain conditions.  If you wish to embed Nmap      *
+ * technology into proprietary software, we sell alternative licenses      *
+ * (contact sales@insecure.com).  Dozens of software vendors already       *
+ * license Nmap technology such as host discovery, port scanning, OS       *
+ * detection, and version detection.                                       *
  *                                                                         *
  * Note that the GPL places important restrictions on "derived works", yet *
  * it does not provide a detailed definition of that term.  To avoid       *
@@ -25,9 +25,12 @@
  * following:                                                              *
  * o Integrates source code from Nmap                                      *
  * o Reads or includes Nmap copyrighted data files, such as                *
- *   nmap-os-fingerprints or nmap-service-probes.                          *
- * o Executes Nmap                                                         *
- * o Integrates/includes/aggregates Nmap into an executable installer      *
+ *   nmap-os-db or nmap-service-probes.                                    *
+ * o Executes Nmap and parses the results (as opposed to typical shell or  *
+ *   execution-menu apps, which simply display raw Nmap output and so are  *
+ *   not derivative works.)                                                * 
+ * o Integrates/includes/aggregates Nmap into a proprietary executable     *
+ *   installer, such as those produced by InstallShield.                   *
  * o Links to a library or executes a program that does any of the above   *
  *                                                                         *
  * The term "Nmap" should be taken to also include any portions or derived *
@@ -36,7 +39,7 @@
  * These restrictions only apply when you actually redistribute Nmap.  For *
  * example, nothing stops you from writing and selling a proprietary       *
  * front-end to Nmap.  Just distribute it by itself, and point people to   *
- * http://www.insecure.org/nmap/ to download Nmap.                         *
+ * http://nmap.org to download Nmap.                                       *
  *                                                                         *
  * We don't consider these to be added restrictions on top of the GPL, but *
  * just a clarification of how we interpret "derived works" as it applies  *
@@ -48,14 +51,23 @@
  * If you have any questions about the GPL licensing restrictions on using *
  * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
  * we also offer alternative license to integrate Nmap into proprietary    *
- * applications and appliances.  These contracts have been sold to many    *
- * security vendors, and generally include a perpetual license as well as  *
- * providing for priority support and updates as well as helping to fund   *
- * the continued development of Nmap technology.  Please email             *
+ * applications and appliances.  These contracts have been sold to dozens  *
+ * of software vendors, and generally include a perpetual license as well  *
+ * as providing for priority support and updates as well as helping to     *
+ * fund the continued development of Nmap technology.  Please email        *
  * sales@insecure.com for further information.                             *
  *                                                                         *
+ * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+ * permission to link the code of this program with any version of the     *
+ * OpenSSL library which is distributed under a license identical to that  *
+ * listed in the included COPYING.OpenSSL file, and distribute linked      *
+ * combinations including the two. You must obey the GNU GPL in all        *
+ * respects for all of the code used other than OpenSSL.  If you modify    *
+ * this file, you may extend this exception to your version of the file,   *
+ * but you are not obligated to do so.                                     *
+ *                                                                         *
  * If you received these files with a written license agreement or         *
- * contract stating terms other than the (GPL) terms above, then that      *
+ * contract stating terms other than the terms above, then that            *
  * alternative license agreement takes precedence over these comments.     *
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
@@ -66,7 +78,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * Insecure.Org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -80,12 +92,13 @@
  * This program is distributed in the hope that it will be useful, but     *
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
- * General Public License for more details at                              *
- * http://www.gnu.org/copyleft/gpl.html .                                  *
+ * General Public License v2.0 for more details at                         *
+ * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
+ * included with Nmap.                                                     *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: Target.h,v 1.12 2004/04/19 02:02:23 fyodor Exp $ */
+/* $Id: Target.h 7640 2008-05-22 20:45:32Z fyodor $ */
 
 #ifndef TARGET_H
 #define TARGET_H
@@ -93,6 +106,29 @@
 #include "nmap.h"
 #include "FingerPrintResults.h"
 
+#ifndef NOLUA
+#include "nse_main.h"
+#endif
+
+#include "portreasons.h"
+#include "portlist.h"
+#include "tcpip.h"
+
+#ifndef INET6_ADDRSTRLEN
+#define INET6_ADDRSTRLEN 46
+#endif
+
+enum osscan_flags {
+	OS_NOTPERF=0, OS_PERF, OS_PERF_UNREL
+};
+
+struct host_timeout_nfo {
+  unsigned long msecs_used; /* How many msecs has this Target used? */
+  bool toclock_running; /* Is the clock running right now? */
+  struct timeval toclock_start; /* When did the clock start? */
+  time_t host_start, host_end; /* The absolute start and end for this host */
+};
+
 class Target {
  public: /* For now ... a lot of the data members should be made private */
   Target();
@@ -103,7 +139,8 @@ class Target {
   /* Fills a sockaddr_storage with the AF_INET or AF_INET6 address
      information of the target.  This is a preferred way to get the
      address since it is portable for IPv6 hosts.  Returns 0 for
-     success. */
+     success. ss_len must be provided.  It is not examined, but is set
+     to the size of the sockaddr copied in. */
   int TargetSockAddr(struct sockaddr_storage *ss, size_t *ss_len);
   /* Note that it is OK to pass in a sockaddr_in or sockaddr_in6 casted
      to sockaddr_storage */
@@ -131,7 +168,7 @@ class Target {
      order
   */
   void setHostName(char *name);
-  /* Generates the a printable string consisting of the host's IP
+  /* Generates a printable string consisting of the host's IP
      address and hostname (if available).  Eg "www.insecure.org
      (64.71.184.53)" or "fe80::202:e3ff:fe14:1102".  The name is
      written into the buffer provided, which is also returned.  Results
@@ -140,42 +177,116 @@ class Target {
   /* This next version returns a STATIC buffer -- so no concurrency */
   const char *NameIP();
 
+  /* Give the name from the last setTargetName() call, which is the 
+   name of the target given on the command line if it's a named
+   host. */
+  const char *TargetName() { return targetname; }
+  /* You can set to NULL to erase a name.  The targetname is blown
+     away when you setTargetSockAddr(), so make sure you do these in proper
+     order
+  */
+  void setTargetName(char *name);
+
+  /* If the host is directly connected on a network, set and retrieve
+     that information here.  directlyConnected() will abort if it hasn't
+     been set yet.  */
+  void setDirectlyConnected(bool connected);
+  bool directlyConnected();
+  int directlyConnectedOrUnset(); /* 1-directly connected, 0-no, -1-we don't know*/
+
+  /* If the host is NOT directly connected, you can set the next hop
+     value here. It is OK to pass in a sockaddr_in or sockaddr_in6
+     casted to sockaddr_storage*/
+  void setNextHop(struct sockaddr_storage *next_hop, size_t next_hop_len);
+  /* Returns the next hop for sending packets to this host.  Returns true if
+     next_hop was filled in.  It might be false, for example, if
+     next_hop has never been set */
+  bool nextHop(struct sockaddr_storage *next_hop, size_t *next_hop_len);
+
+  /* Sets the interface type to one of: 
+     devt_ethernet, devt_loopback, devt_p2p, devt_other
+   */
+  void setIfType(devtype iftype) { interface_type = iftype; }
+  /* Returns -1 if it has not yet been set with setIfType() */
+  devtype ifType() { return interface_type; }
+  /* Starts the timeout clock for the host running (e.g. you are
+     beginning a scan).  If you do not have the current time handy,
+     you can pass in NULL.  When done, call stopTimeOutClock (it will
+     also automatically be stopped of timedOut() returns true) */
+  void startTimeOutClock(const struct timeval *now);
+  /* The complement to startTimeOutClock. */
+  void stopTimeOutClock(const struct timeval *now);
+  /* Is the timeout clock currently running? */
+  bool timeOutClockRunning() { return htn.toclock_running; }
+  /* Returns whether the host is timedout.  If the timeoutclock is
+     running, counts elapsed time for that.  Pass NULL if you don't have the
+     current time handy.  You might as well also pass NULL if the
+     clock is not running, as the func won't need the time. */
+  bool timedOut(const struct timeval *now);
+  /* Return time_t for the start and end time of this host */
+  time_t StartTime() { return htn.host_start; }
+  time_t EndTime() { return htn.host_end; }
+
   /* Takes a 6-byte MAC address */
   int setMACAddress(const u8 *addy);
+  int setSrcMACAddress(const u8 *addy);
+  int setNextHopMACAddress(const u8 *addy); // this should be the target's own MAC if directlyConnected()
+
   /* Returns a pointer to 6-byte MAC address, or NULL if none is set */
   const u8 *MACAddress();
+  const u8 *SrcMACAddress();
+  const u8 *NextHopMACAddress();
+
+/* Set the device names so that they can be returned by deviceName()
+   and deviceFullName().  The normal name may not include alias
+   qualifier, while the full name may include it (e.g. "eth1:1").  If
+   these are non-null, they will overwrite the stored version */
+  void setDeviceNames(const char *name, const char *fullname);
+  const char *deviceName();
+  const char *deviceFullName();
+
+  int osscanPerformed(void);
+  void osscanSetFlag(int flag);
 
   struct seq_info seq;
-  FingerPrintResults *FPR;
-  int osscan_performed; /* nonzero if an osscan was performed */
+  int distance;
+  FingerPrintResults *FPR; /* FP results get by the OS scan system. */
   PortList ports;
-  /*
-  unsigned int up;
-  unsigned int down; */
+
+  // unsigned int up;
+  // unsigned int down;
   int wierd_responses; /* echo responses from other addresses, Ie a network broadcast address */
   unsigned int flags; /* HOST_UP, HOST_DOWN, HOST_FIREWALLED, HOST_BROADCAST (instead of HOST_BROADCAST use wierd_responses */
   struct timeout_info to;
-  struct timeval host_timeout;
-  struct firewallmodeinfo firewallmode; /* For supporting "firewall mode" speed optimisations */
-  int timedout; /* Nonzero if continued scanning should be aborted due to
-		   timeout  */
-  char device[64]; /* The device we transmit on -- make sure to adjust some str* calls if I ever change this*/
-
- private:
   char *hostname; // Null if unable to resolve or unset
+  char * targetname; // The name of the target host given on the commmand line if it is a named host
+
+#ifndef NOLUA
+  ScriptResults scriptResults;
+#endif
+
+  state_reason_t reason;
+
+  private:
   void Initialize();
   void FreeInternal(); // Free memory allocated inside this object
  // Creates a "presentation" formatted string out of the IPv4/IPv6 address
   void GenerateIPString();
-  struct sockaddr_storage targetsock, sourcesock;
-  size_t targetsocklen, sourcesocklen;
-#ifndef INET6_ADDRSTRLEN
-#define INET6_ADDRSTRLEN 46
-#endif
+  struct sockaddr_storage targetsock, sourcesock, nexthopsock;
+  size_t targetsocklen, sourcesocklen, nexthopsocklen;
+  int directly_connected; // -1 = unset; 0 = no; 1 = yes
   char targetipstring[INET6_ADDRSTRLEN];
   char *nameIPBuf; /* for the NameIP(void) function to return */
-  u8 MACaddress[6];
-  bool MACaddress_set;
+  u8 MACaddress[6], SrcMACaddress[6], NextHopMACaddress[6];  
+  bool MACaddress_set, SrcMACaddress_set, NextHopMACaddress_set;
+  struct host_timeout_nfo htn;
+  devtype interface_type;
+  char devname[32];
+	char devfullname[32];
+  /* 0 (OS_NOTPERF) if os detection not performed
+   * 1 (OS_PERF) if os detection performed 
+   * 2 (OS_PERF_UNREL) if an unreliable os detection has been performed */
+  int osscan_flag; 
 };
 
 #endif /* TARGET_H */
