@@ -101,7 +101,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: idle_scan.cc 7752 2008-05-29 07:49:37Z michael $ */
+/* $Id: idle_scan.cc 8124 2008-06-11 06:11:52Z kris $ */
 
 #include "idle_scan.h"
 #include "timing.h"
@@ -132,7 +132,7 @@ struct idle_proxy_info {
   u16 probe_port; /* The port we use for probing IP ID infoz */
   u16 max_groupsz; /* We won't test groups larger than this ... */
   u16 min_groupsz; /* We won't allow the group size to fall below this
-		      level.  Affected by --min_parallelism */
+		      level.  Affected by --min-parallelism */
   double current_groupsz; /* Current group size being used ... depends on
                           conditions ... won't be higher than
                           max_groupsz */
@@ -226,7 +226,7 @@ static int ipid_proxy_probe(struct idle_proxy_info *proxy, int *probes_sent,
 	    }
 	    else if (o.debugging > 1) {
 	      error("Received unexpected response packet from %s during IP ID zombie probing:", inet_ntoa(ip->ip_src));
-	      readtcppacket( (unsigned char *) ip,ntohs(ip->ip_len));
+	      readtcppacket( (unsigned char *) ip,MIN(ntohs(ip->ip_len), bytes));
 	    }
 	    continue;
 	  }
