@@ -97,7 +97,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: nbase_misc.c 7641 2008-05-22 20:45:49Z fyodor $ */
+/* $Id: nbase_misc.c 7896 2008-06-03 15:58:02Z michael $ */
 
 #ifndef WIN32
 #include <errno.h>
@@ -151,14 +151,14 @@ const char *inet_ntop_ez(struct sockaddr_storage *ss, size_t sslen) {
     return inet_ntop(AF_INET, &sin->sin_addr, str, sizeof(str));
   } 
 #if HAVE_IPV6
-  else {
-    assert(sin->sin_family == AF_INET6);
+  else if(sin->sin_family == AF_INET6) {
     if (sslen < sizeof(struct sockaddr_in6))
       return NULL;
     return inet_ntop(AF_INET6, &sin6->sin6_addr, str, sizeof(str));
   } 
 #endif
-
+  //Some laptops report the ip and address family of disabled wifi cards as null
+  //so yes, we will hit this sometimes.
   return NULL;
 }
 
