@@ -1,11 +1,5 @@
 #include "nse_main.h"
 
-extern "C" {
-	#include "lua.h"
-	#include "lualib.h"
-	#include "lauxlib.h"
-}
-
 #include "nse_init.h"
 #include "nse_nsock.h"
 #include "nse_nmaplib.h"
@@ -70,6 +64,9 @@ int process_mainloop(lua_State* L);
 int process_waiting2running(lua_State* L, int resume_arguments);
 int process_finalize(lua_State* L, unsigned int registry_idx);
 
+// post execution
+int cleanup_threads(std::list<struct thread_record> trs);
+
 static int panic (lua_State *L)
 {
   const char *err = lua_tostring(L, 1);
@@ -80,7 +77,7 @@ static int panic (lua_State *L)
 int script_updatedb (void)
 {
   int status;
-  int ret;
+  int ret = SCRIPT_ENGINE_SUCCESS;
   lua_State *L;
 
   SCRIPT_ENGINE_VERBOSE(
@@ -298,6 +295,7 @@ finishup:
 			log_write(LOG_STDOUT, "%s: Script scanning completed.\n", SCRIPT_ENGINE);
 			)
 	lua_close(L);
+	cleanup_threads(torun_threads);
 	torun_scripts.clear();
 	if(status != SCRIPT_ENGINE_SUCCESS) {
 		error("%s: Aborting script scan.", SCRIPT_ENGINE);
@@ -360,9 +358,9 @@ int process_mainloop(lua_State *L) {
 			}
 
 
-		while(running_scripts.begin() != running_scripts.end()){
+        while (!running_scripts.empty()) {
 			current = *(running_scripts.begin());
-	
+
 			if (current.rr->host->timedOut(&now))
 				state = LUA_ERRRUN;
 			else
@@ -470,7 +468,8 @@ int process_waiting2running(lua_State* L, int resume_arguments) {
 
 	// put the thread back into the running
 	// queue
-	running_scripts.push_front((*iter));
+	//running_scripts.push_front((*iter));
+	running_scripts.push_back((*iter));
 	waiting_scripts.erase(iter);
 
 	return SCRIPT_ENGINE_SUCCESS;
@@ -751,4 +750,13 @@ int process_preparethread(lua_State* L, struct run_record rr, struct thread_reco
 	return SCRIPT_ENGINE_SUCCESS;
 }
 
+int cleanup_threads(std::list<struct thread_record> trs)
+{
+	std::list<struct thread_record>::iterator triter;
+
+	for (triter = trs.begin(); triter != trs.end(); triter++)
+		free((*triter).rr);
+
+	return SCRIPT_ENGINE_SUCCESS;
+}
 
