@@ -6,7 +6,7 @@
  *                                                                         *
  ***********************IMPORTANT NSOCK LICENSE TERMS***********************
  *                                                                         *
- * The nsock parallel socket event library is (C) 1999-2004 Insecure.Com   *
+ * The nsock parallel socket event library is (C) 1999-2008 Insecure.Com   *
  * LLC This library is free software; you may redistribute and/or          *
  * modify it under the terms of the GNU General Public License as          *
  * published by the Free Software Foundation; Version 2.  This guarantees  *
@@ -18,7 +18,7 @@
  * As a special exception to the GPL terms, Insecure.Com LLC grants        *
  * permission to link the code of this program with any version of the     *
  * OpenSSL library which is distributed under a license identical to that  *
- * listed in the included Copying.OpenSSL file, and distribute linked      *
+ * listed in the included COPYING.OpenSSL file, and distribute linked      *
  * combinations including the two. You must obey the GNU GPL in all        *
  * respects for all of the code used other than OpenSSL.  If you modify    *
  * this file, you may extend this exception to your version of the file,   *
@@ -36,7 +36,7 @@
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
  * to fyodor@insecure.org for possible incorporation into the main         *
- * distribution.  By sending these changes to Fyodor or one the            *
+ * distribution.  By sending these changes to Fyodor or one of the         *
  * insecure.org development mailing lists, it is assumed that you are      *
  * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
  * to reuse, modify, and relicense the code.  Nmap will always be          *
@@ -50,12 +50,12 @@
  * This program is distributed in the hope that it will be useful, but     *
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
- * General Public License for more details (                               *
- * http://www.gnu.org/copyleft/gpl.html ).                                 *
+ * General Public License v2.0 for more details                            *
+ * (http://www.gnu.org/licenses/gpl-2.0.html).                             *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: nsock_internal.h,v 1.19 2004/10/12 09:34:12 fyodor Exp $ */
+/* $Id: nsock_internal.h 7327 2008-05-05 04:10:20Z fyodor $ */
 
 #ifndef NSOCK_INTERNAL_H
 #define NSOCK_INTERNAL_H
@@ -136,6 +136,9 @@ struct event_lists {
   gh_list read_events;
   gh_list write_events;
   gh_list timer_events;
+  #if HAVE_PCAP
+  gh_list pcap_read_events;
+  #endif 
   gh_list free_events; /* When an event is deleted, we stick it here for
 			  later reuse */
   struct timeval next_ev; /* The soonest time that either a timer event goes
@@ -226,6 +229,8 @@ struct msiod {
   unsigned long id; /* Every iod has an id which is always unique for the
 		       same nspool (unless you create billions of them) */
   void *userdata;
+  
+  void *pcap;	   /* Pointer to mspcap struct (used only if pcap support is included) */
 };
 
 
@@ -321,6 +326,11 @@ void handle_write_result(mspool *ms, msevent *nse,
 void handle_timer_result(mspool *ms, msevent *nse, 
 			 enum nse_status status);
 
+#if HAVE_PCAP
+void handle_pcap_read_result(mspool *ms, msevent *nse, 
+			       enum nse_status status);
+#endif
+
 void nsock_trace(mspool *ms, char *fmt, ...)
      __attribute__ ((format (printf, 2, 3)));
 
