@@ -101,7 +101,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: output.cc 7764 2008-05-29 20:05:02Z david $ */
+/* $Id: output.cc 8494 2008-06-28 21:23:39Z fyodor $ */
 
 #include "output.h"
 #include "osscan.h"
@@ -174,9 +174,8 @@ static char* xml_sf_convert (const char* str) {
   char *temp = (char *) safe_malloc(strlen(str) + 1);
   char *dst = temp, *src = (char *)str;
   char *ampptr = 0;
-  int charcount = 0;
 
-  while(*src && charcount < 2035) { /* 2048 - 14 */
+  while(*src) {
     if (strncmp(src, "\nSF:", 4) == 0) {
       src += 4;
       continue;
@@ -189,7 +188,6 @@ static char* xml_sf_convert (const char* str) {
       ampptr = 0;
     }
     *dst++ = *src++;
-    charcount++;
   }
   if (ampptr != 0) {
     *ampptr = '\0';
@@ -202,20 +200,22 @@ static char* xml_sf_convert (const char* str) {
 
 
 // Creates an XML <service> element for the information given in
-// serviceDeduction.  It will be 0-length if none is neccessary.
-// returns 0 for success.
-static int getServiceXMLBuf(struct serviceDeductions *sd, char *xmlbuf, 
-		     unsigned int xmlbuflen) {
+// serviceDeduction.  This function should only be called if ether
+// the service name or the service fingerprint is non-null.
+// Returns a pointer to a buffer containing the element,
+// you will have to call free on it.
+static char * getServiceXMLBuf(struct serviceDeductions *sd) {
   string versionxmlstring = "";
   char rpcbuf[128];
+  char confBuf[20];
   char *xml_product = NULL, *xml_version = NULL, *xml_extrainfo = NULL;
   char *xml_hostname = NULL, *xml_ostype = NULL, *xml_devicetype = NULL;
   char *xml_servicefp = NULL, *xml_servicefp_temp = NULL;
 
-  if (xmlbuflen < 1) return -1;
-  xmlbuf[0] = '\0';  
-  if (!sd->name && !sd->service_fp) return 0;
 
+  versionxmlstring =  "<service name=\"";
+  versionxmlstring += sd->name? sd->name : "unknown";
+  versionxmlstring += "\"";
   if (sd->product) {
     xml_product = xml_convert(sd->product);
     versionxmlstring += " product=\"";
@@ -280,25 +280,89 @@ static int getServiceXMLBuf(struct serviceDeductions *sd, char *xmlbuf,
 	     sd->rpc_program, sd->rpc_lowver, sd->rpc_highver);
   } else rpcbuf[0] = '\0';
 
-  Snprintf(xmlbuf, xmlbuflen, 
-	   "<service name=\"%s\"%s %smethod=\"%s\" conf=\"%d\"%s />", 
-	   sd->name? sd->name : "unknown",
-	   versionxmlstring.c_str(),
-	   (sd->service_tunnel == SERVICE_TUNNEL_SSL)? "tunnel=\"ssl\" " : "",
-	   (sd->dtype == SERVICE_DETECTION_TABLE)? "table" : "probed", 
-
-	   sd->name_confidence, rpcbuf);
-
-  return 0;
+  versionxmlstring += " ";
+  versionxmlstring += (sd->service_tunnel == SERVICE_TUNNEL_SSL)? "tunnel=\"ssl\" " : "";
+  versionxmlstring += "method=\"";
+  versionxmlstring += (sd->dtype == SERVICE_DETECTION_TABLE)? "table" : "probed";
+  versionxmlstring += "\" conf=\"";
+  Snprintf(confBuf,20,"%i",sd->name_confidence);
+  versionxmlstring += confBuf;
+  versionxmlstring += "\"";
+  versionxmlstring += rpcbuf;
+  versionxmlstring += " />";
+  return strdup(versionxmlstring.c_str());
 }
 
+#ifdef WIN32
+/* From tcpip.cc. */
+bool DnetName2PcapName(const char *dnetdev, char *pcapdev, int pcapdevlen);
+
+/* Display the mapping from libdnet interface names (like "eth0") to WinPcap
+   interface names (like "\Device\NPF_{...}"). This is the same mapping used by
+   eth_open and so can help diagnose connection problems.  Additionally display
+   WinPcap interface names that are not mapped to by any libdnet name, in other
+   words the names of interfaces Nmap has no way of using.*/
+static void print_iflist_pcap_mapping(const struct interface_info *iflist, int numifs) {
+  pcap_if_t *pcap_ifs;
+  list<const pcap_if_t *> leftover_pcap_ifs;
+  list<const pcap_if_t *>::iterator leftover_p;
+  int i;
+
+  /* Build a list of "leftover" libpcap interfaces. Initially it contains all
+     the interfaces. */
+  pcap_ifs = getpcapinterfaces();
+  for (const pcap_if_t *p = pcap_ifs; p != NULL; p = p->next)
+    leftover_pcap_ifs.push_front(p);
+
+  if (numifs > 0 || !leftover_pcap_ifs.empty()) {
+    NmapOutputTable Tbl(1 + numifs + leftover_pcap_ifs.size(), 2);
+
+    Tbl.addItem(0, 0, false, "DEV");
+    Tbl.addItem(0, 1, false, "WINDEVICE");
+
+    /* Show the libdnet names and what they map to. */
+    for (i = 0; i < numifs; i++) {
+      char pcap_name[1024];
+
+      if (DnetName2PcapName(iflist[i].devname, pcap_name, sizeof(pcap_name))) {
+        /* We got a name. Remove it from the list of leftovers. */
+        list<const pcap_if_t *>::iterator next;
+        for (leftover_p = leftover_pcap_ifs.begin(); leftover_p != leftover_pcap_ifs.end(); leftover_p = next) {
+          next = leftover_p;
+          next++;
+          if (strcmp((*leftover_p)->name, pcap_name) == 0)
+            leftover_pcap_ifs.erase(leftover_p);
+        }
+      } else {
+        Strncpy(pcap_name, "<none>", sizeof(pcap_name));
+      }
+
+      Tbl.addItem(i + 1, 0, false, iflist[i].devname);
+      Tbl.addItem(i + 1, 1, true, pcap_name);
+    }
+
+    /* Show the "leftover" libpcap interface names (those without a libdnet
+       name that maps to them). */
+    for (leftover_p = leftover_pcap_ifs.begin(); leftover_p != leftover_pcap_ifs.end(); leftover_p++) {
+      Tbl.addItem(i + 1, 0, false, "<none>");
+      Tbl.addItem(i + 1, 1, false, (*leftover_p)->name);
+      i++;
+    }
+
+    log_write(LOG_PLAIN, "%s\n", Tbl.printableTable(NULL));
+    log_flush_all();
+  }
+
+  pcap_freealldevs(pcap_ifs);
+}
+#endif
+
 /* Print a detailed list of Nmap interfaces and routes to
    normal/skiddy/stdout output */
 int print_iflist(void) {
   int numifs = 0, numroutes = 0;
   struct interface_info *iflist;
   struct sys_route *routes;
-  pcap_if_t *p_ifaces, *p_iface_iter;
   NmapOutputTable *Tbl = NULL;
   iflist = getinterfaces(&numifs);
   int i;
@@ -334,25 +398,11 @@ int print_iflist(void) {
     log_flush_all();
     delete Tbl;
   }
-  
-  /* Display windows device names */
-  if((p_ifaces = getpcapinterfaces()) != NULL && numifs > 0) {
-    Tbl = new NmapOutputTable(numifs+1, 2);
-    Tbl->addItem(0, 0, false, "DEV");
-    Tbl->addItem(0, 1, false, "WINDEVICE");
-    i = numifs;
 
-    for(p_iface_iter = p_ifaces; p_iface_iter != NULL && i >= 1; i--) {	
-      Tbl->addItem(i, 0, false, iflist[i-1].devname);
-      Tbl->addItem(i, 1, false, p_iface_iter->name);
-      p_iface_iter = p_iface_iter->next;
-    }
-
-    log_write(LOG_PLAIN, "%s\n", Tbl->printableTable(NULL));
-    log_flush_all();
-    delete Tbl;
-    pcap_freealldevs(p_ifaces);
-  }
+#ifdef WIN32
+  /* Print the libdnet->libpcap interface name mapping. */
+  print_iflist_pcap_mapping(iflist, numifs);
+#endif
 
   /* OK -- time to handle routes */
   routes = getsysroutes(&numroutes);
@@ -432,10 +482,10 @@ void printportoutput(Target *currenths, PortList *plist) {
   char rpcinfo[64];
   char rpcmachineinfo[64];
   char portinfo[64];
-  char xmlbuf[2560];
   char grepvers[256];
   char grepown[64];
   char *p;
+  char * xmlBuf=NULL;
   const char *state;
   char serviceinfo[64];
   char *name=NULL;
@@ -717,9 +767,15 @@ void printportoutput(Target *currenths, PortList *plist) {
 	if (current->owner && *current->owner) {
 	  log_write(LOG_XML, "<owner name=\"%s\" />", current->owner);
 	}
-	if (getServiceXMLBuf(&sd, xmlbuf, sizeof(xmlbuf)) == 0)
-	  if (*xmlbuf)
-	    log_write(LOG_XML, "%s", xmlbuf);
+	
+	if (sd.name || sd.service_fp){
+		xmlBuf = getServiceXMLBuf(&sd);
+		if(xmlBuf){
+			log_write(LOG_XML, "%s", xmlBuf);
+			free(xmlBuf);
+			xmlBuf=NULL;
+		}
+	}
 
 	rowno++;
 #ifndef NOLUA	
@@ -998,7 +1054,7 @@ void log_vwrite(int logt, const char *fmt, va_list ap) {
 	  /* Windows seems to just give -1 rather than the amount of space we 
 	     would need.  So lets just gulp up a huge amount in the hope it
 	     will be enough */
-	  writebuflen *= 100;
+	  writebuflen *= 150;
 	}
 	writebuf = (char *) safe_realloc(writebuf, writebuflen);
 	len = Vsnprintf(writebuf, writebuflen, fmt, apcopy);
