@@ -96,7 +96,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: portlist.cc 7640 2008-05-22 20:45:32Z fyodor $ */
+/* $Id: portlist.cc 8081 2008-06-09 16:54:08Z kris $ */
 
 
 #include "portlist.h"
@@ -150,6 +150,11 @@ Port::~Port() {
    free(serviceprobe_service);
  if (serviceprobe_fp)
    free(serviceprobe_fp);
+ if (o.script) {
+   ScriptResults::iterator sriter;
+   for (sriter = scriptResults.begin(); sriter != scriptResults.end(); sriter++)
+     free((*sriter).id);
+ }
 }
 
 // Uses the sd->{product,version,extrainfo} if available to fill
