@@ -98,7 +98,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: tcpip.h 7640 2008-05-22 20:45:32Z fyodor $ */
+/* $Id: tcpip.h 8050 2008-06-08 15:34:07Z kris $ */
 
 
 #ifndef TCPIP_H
@@ -232,7 +232,7 @@ typedef enum { devt_ethernet, devt_loopback, devt_p2p, devt_other  } devtype;
 
 
 /* Used for tracing all packets sent or received (eg the
-   --packet_trace option) */
+   --packet-trace option) */
 class PacketTrace {
  public:
   /*  static const int SEND=1;
