@@ -328,7 +328,7 @@ Traceroute::getTracePort (u8 proto, Target * t) {
     u16 filtered_port = 1;
     u16 port = 0;
     int state = -1;
-    struct Port *np;
+    Port *np;
 
     /* Use the first specified port for ping traceroutes */
     if (o.pingscan) {
@@ -435,15 +435,21 @@ Traceroute::readTraceResponses () {
             ip2 = (struct ip *) (((char *) ip) + 4 * ip->ip_hl + 8);
             if (ip2->ip_p == IPPROTO_TCP) {
                 tcp = (struct tcp_hdr *) ((u8 *) ip2 + ip2->ip_hl * 4);
-                sport = htons (tcp->th_sport);
+                if (ntohs(ip2->ip_len) - (ip2->ip_hl * 4) < 2)
+                    break;
+                sport = ntohs (tcp->th_sport);
             } else if (ip2->ip_p == IPPROTO_UDP) {
                 udp = (struct udp_hdr *) ((u8 *) ip2 + ip2->ip_hl * 4);
-                sport = htons (udp->uh_sport);
+                if (ntohs(ip2->ip_len) - (ip2->ip_hl * 4) < 2)
+                    break;
+                sport = ntohs (udp->uh_sport);
             } else if (ip2->ip_p == IPPROTO_ICMP) {
                 icmp2 = (struct icmp *) ((char *) ip2 + 4 * ip2->ip_hl);
+                if (ntohs(ip2->ip_len) - (ip2->ip_hl * 4) < 8)
+                    break;
                 sport = ntohs(icmp2->icmp_id);
             } else {
-                sport = htons(ip2->ip_id);
+                sport = ntohs(ip2->ip_id);
             }
             ipaddr = ip2->ip_dst.s_addr;
         }
@@ -534,8 +540,8 @@ Traceroute::readTraceResponses () {
         else
             break;
 
-        if (tg->TraceProbes.find (htons (tcp->th_dport)) != tg->TraceProbes.end ())
-            tp = tg->TraceProbes[htons (tcp->th_dport)];
+        if (tg->TraceProbes.find (ntohs (tcp->th_dport)) != tg->TraceProbes.end ())
+            tp = tg->TraceProbes[ntohs (tcp->th_dport)];
         else
             break;
 
@@ -578,8 +584,8 @@ Traceroute::readTraceResponses () {
         else
             break;
 
-        if (tg->TraceProbes.find (htons (udp->uh_dport)) != tg->TraceProbes.end ())
-            tp = tg->TraceProbes[htons (udp->uh_dport)];
+        if (tg->TraceProbes.find (ntohs (udp->uh_dport)) != tg->TraceProbes.end ())
+            tp = tg->TraceProbes[ntohs (udp->uh_dport)];
         else
             break;
 
