@@ -43,9 +43,8 @@ INSTALLED_FILES_NAME = "INSTALLED_FILES"
 # Directories for POSIX operating systems
 # These are created after a "install" or "py2exe" command
 # These directories are relative to the installation or dist directory
-pixmaps_dir = os.path.join('share', 'pixmaps')
-icons_dir = os.path.join('share', 'icons')
 data_dir = os.path.join('share', APP_NAME)
+pixmaps_dir = os.path.join(data_dir, 'pixmaps')
 locale_dir = os.path.join(data_dir, 'locale')
 config_dir = os.path.join(data_dir, 'config')
 docs_dir = os.path.join(data_dir, 'docs')
@@ -74,9 +73,6 @@ data_files = [ (pixmaps_dir, glob(os.path.join(pixmaps_dir, '*.svg')) +
                (misc_dir, glob(os.path.join(misc_dir, '*.dmp')) +
                           glob(os.path.join(misc_dir, '*.xml'))), 
 
-               (icons_dir, glob(os.path.join('share', 'icons', '*.ico'))+
-                           glob(os.path.join('share', 'icons', '*.png'))),
-
                (docs_dir, [os.path.join(docs_dir, 'help.html')])]
 
 # Add i18n files to data_files list
@@ -153,7 +149,7 @@ class my_install(install):
 
         uninstaller = """\
 #!/usr/bin/env python
-import os, os.path, sys
+import errno, os, os.path, sys
 
 print 'Uninstall %(name)s %(version)s'
 
@@ -280,8 +276,7 @@ for dir in dirs:
                              "DOCS_DIR": os.path.join(self.prefix, docs_dir),
                              "LOCALE_DIR": os.path.join(self.prefix, locale_dir),
                              "MISC_DIR": os.path.join(self.prefix, misc_dir),
-                             "PIXMAPS_DIR": os.path.join(self.prefix, pixmaps_dir),
-                             "ICONS_DIR": os.path.join(self.prefix, icons_dir)}
+                             "PIXMAPS_DIR": os.path.join(self.prefix, pixmaps_dir)}
 
         # Find and read the Paths.py file.
         pcontent = ""
@@ -413,7 +408,7 @@ if 'py2exe' in sys.argv:
     WINDOWS_SETUP_ARGS = {
         'zipfile': None,
         'windows': [{"script": APP_NAME,
-                     "icon_resources": [(1, os.path.join("share", "icons", "nmap-eye.ico"))]}],
+                     "icon_resources": [(1, "install_scripts/windows/nmap-eye.ico")]}],
         'options': {"py2exe": {
             "compressed": 1,
             "optimize":2,
